==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement.md <==
# AwsRoboMakerFleetManagement


```text
aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement
```

```text
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')
```



| Illustration | AwsRoboMakerFleetManagement | AwsRoboMakerFleetManagementCard | AwsRoboMakerFleetManagementGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement.png) | ![illustration for AwsRoboMakerFleetManagement](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement.Local.png) | ![illustration for AwsRoboMakerFleetManagementCard](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagementCard.Local.png) | ![illustration for AwsRoboMakerFleetManagementGroup](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagementGroup.Local.png) |




## AwsRoboMakerFleetManagement

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label')
@enduml
```

## AwsRoboMakerFleetManagementCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

## AwsRoboMakerFleetManagementGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement.md <==
# AwsRoboMakerFleetManagement


```text
aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement
```

```text
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')
```



| Illustration | AwsRoboMakerFleetManagement | AwsRoboMakerFleetManagementCard | AwsRoboMakerFleetManagementGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement.png) | ![illustration for AwsRoboMakerFleetManagement](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement.Local.png) | ![illustration for AwsRoboMakerFleetManagementCard](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagementCard.Local.png) | ![illustration for AwsRoboMakerFleetManagementGroup](../../../aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagementGroup.Local.png) |




## AwsRoboMakerFleetManagement

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label')
@enduml
```

## AwsRoboMakerFleetManagementCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

## AwsRoboMakerFleetManagementGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-20210730/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
